A safe version of shiny notifications, mostly for used in testing
Source:R/functions.R
safely_showNotification.RdA safe version of shiny notifications, mostly for used in testing
R/functions.R
safely_showNotification.RdA safe version of shiny notifications, mostly for used in testing